@@ -1,4 +1,4 @@
-from .compat import urlparse, urljoin
+from .compat import urlparse, urljoin, urldefrag
 
 __all__ = ("apply_base_url", "is_url_with_scheme", "is_absolute_url")
 
@@ -14,7 +14,7 @@ def is_url_with_scheme(url):
 def apply_base_url(discovered_url, site_base_url, resource_url=None):
     url = urlparse(discovered_url)
     if url.scheme in ["http", "https"] and url.netloc:
-        return discovered_url
+        return urldefrag(discovered_url)[0]
     if resource_url and is_url_with_scheme(resource_url):
         site_base_url = resource_url
-    return urljoin(site_base_url, discovered_url)
+    return urldefrag(urljoin(site_base_url, discovered_url))[0]
